==> spip_3.2.11.orig.tar.xz: plugins-dist/mots/lang/mots_co.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mots?lang_cible=co
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_conseil_selection_mot_cle' => '<b>Gruppu importante :</b> Hè cunsigliatu di sceglie un segnu in stu gruppu.',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'l’amministratori di u situ',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'i scrittori',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'i visitori di u situ pùbblicu quand’elli scrivenu un messagiu in un foru.',

	// I
	'icone_creation_groupe_mots' => 'Creà un novu gruppu di parulle',
	'icone_creation_mots_cles' => 'Creà un nuvellu segnu',
	'icone_modif_groupe_mots' => 'Mudificà u gruppu di parulle',
	'icone_modifier_mot' => 'Mudificà stu segnu',
	'icone_mots_cles' => 'Segni',
	'icone_supprimer_groupe_mots' => 'Sguassà stu gruppu',
	'icone_voir_tous_mots_cles' => 'Vede tutti i segni',
	'info_articles_lies_mot' => 'L’artìculi alleati à stu segnu',
	'info_changer_nom_groupe' => 'Scambià u nome di stu gruppu :',
	'info_creation_mots_cles' => 'Create puru è cunfigurate quì e parulle chjave di u situ',
	'info_dans_groupe' => 'In u gruppu :',
	'info_delet_mots_cles' => 'Vulete sguassà u segnu
<b>@titre_mot@</b> (@type_mot@). Essendu questu alleatu à <b>@texte_lie@</b>, vi tocca à cunfirmà sta decisione :', # MODIF
	'info_groupe_important' => 'Gruppu impurtante',
	'info_modifier_mot' => 'Mudificà u segnu :',
	'info_mots_cles' => 'I segni',
	'info_mots_cles_association' => 'I segni di stu gruppu ponu esse assuciati :',
	'info_oui_suppression_mot_cle' => 'vogliu sguassà per sempre stu segnu.',
	'info_question_mots_cles' => 'Vulete aduprà segni in u situ ?',
	'info_qui_attribue_mot_cle' => 'I segni di stu gruppu ponu esse attribuiti da :',
	'info_retirer_mot' => 'Sguassà sta parulla',
	'info_retirer_mots' => 'Sguassà tutte e parulle',
	'info_rubriques_liees_mot' => 'E rùbbriche alleate à stu segnu',
	'info_selection_un_seul_mot_cle' => 'Si pò sceglie <b>un solu segnu</b> à a volta in stu gruppu.', # MODIF
	'info_supprimer_mot' => 'sguassà sta parulla',
	'info_titre_mot_cle' => 'Nome o tìtulu di u segnu',
	'info_un_mot' => 'Una parlla sola à a volta',
	'item_ajout_mots_cles' => 'Auturizà l’usu di segni in i fori',
	'item_non_ajout_mots_cles' => 'Ùn auturizà l’usu di parulle chjave in i fori',
	'item_non_utiliser_config_groupe_mots_cles' => 'Ùn aduprà a cunfigurazione avanzata di i gruppi di segni',
	'item_non_utiliser_mots_cles' => 'Ùn aduprà micca i segni',
	'item_utiliser_config_groupe_mots_cles' => 'Aduprà l cunfigurazione avanzata di i gruppi di segni',
	'item_utiliser_mots_cles' => 'Aduprà i segni',

	// L
	'logo_mot_cle' => 'LOGO DI U SEGNU',

	// T
	'texte_config_groupe_mots_cles' => 'Vulete attivà a cunfigurazione avanzata di i segni,
  indettendu per esempiu chì si pò sceglie un segnu ùnicu per gruppu, o chì un gruppu hè impurtante ... ?', # MODIF
	'texte_mots_cles' => 'I segni permettenu di creà lee temàtiche frà i vostri artìculi,
  duv’elli sianu piazzati à mezu à e diverse rùbbriche.
  Cusì pudete arricchisce a navigazione di u vostru situ, o puru persunalizà a presentazione di l’artìculi in i vostri mudelli.',
	'texte_mots_cles_dans_forum' => 'Vulete auturizà à i visitori l’adopru di i segni in i fori di u situ pùbblicu ? 
  (Attenti : St’upzione hè abbastanza cumplicata à gestisce cum’ellu ci vole.)',
	'texte_nouveau_mot' => 'Nova parulla',
	'titre_config_groupe_mots_cles' => 'Cunfigurazione di i gruppi di segni',
	'titre_gauche_mots_edit' => 'SEGNU NÙMERU :',
	'titre_mots_cles_dans_forum' => 'Segni in u foru di u situ pùbblicu',
	'titre_mots_tous' => 'I segni',
	'titre_nouveau_groupe' => 'Nuvellu gruppu',
	'titre_page_mots_tous' => 'Segni'
);

==> spip_4.4.3+dfsg.orig.tar.xz: plugins-dist/mots/lang/mots_co.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mots?lang_cible=co
// ** ne pas modifier le fichier **

return [

	// A
	'avis_conseil_selection_mot_cle' => '<b>Gruppu importante :</b> Hè cunsigliatu di sceglie un segnu in stu gruppu.',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'l’amministratori di u situ',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'i scrittori',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'i visitori di u situ pùbblicu quand’elli scrivenu un messagiu in un foru.',

	// I
	'icone_creation_groupe_mots' => 'Creà un novu gruppu di parulle',
	'icone_creation_mots_cles' => 'Creà un nuvellu segnu',
	'icone_modif_groupe_mots' => 'Mudificà u gruppu di parulle',
	'icone_modifier_mot' => 'Mudificà stu segnu',
	'icone_mots_cles' => 'Segni',
	'icone_supprimer_groupe_mots' => 'Sguassà stu gruppu',
	'icone_voir_tous_mots_cles' => 'Vede tutti i segni',
	'info_articles_lies_mot' => 'L’artìculi alleati à stu segnu',
	'info_changer_nom_groupe' => 'Scambià u nome di stu gruppu :',
	'info_creation_mots_cles' => 'Create puru è cunfigurate quì e parulle chjave di u situ',
	'info_dans_groupe' => 'In u gruppu :',
	'info_delet_mots_cles' => 'Vulete sguassà u segnu
<b>@titre_mot@</b> (@type_mot@). Essendu questu alleatu à <b>@texte_lie@</b>, vi tocca à cunfirmà sta decisione :', # MODIF
	'info_groupe_important' => 'Gruppu impurtante',
	'info_modifier_mot' => 'Mudificà u segnu :',
	'info_mots_cles' => 'I segni',
	'info_mots_cles_association' => 'I segni di stu gruppu ponu esse assuciati :',
	'info_oui_suppression_mot_cle' => 'vogliu sguassà per sempre stu segnu.',
	'info_question_mots_cles' => 'Vulete aduprà segni in u situ ?',
	'info_qui_attribue_mot_cle' => 'I segni di stu gruppu ponu esse attribuiti da :',
	'info_retirer_mot' => 'Sguassà sta parulla',
	'info_retirer_mots' => 'Sguassà tutte e parulle',
	'info_rubriques_liees_mot' => 'E rùbbriche alleate à stu segnu',
	'info_selection_un_seul_mot_cle' => 'Si pò sceglie <b>un solu segnu</b> à a volta in stu gruppu.', # MODIF
	'info_supprimer_mot' => 'sguassà sta parulla',
	'info_titre_mot_cle' => 'Nome o tìtulu di u segnu',
	'info_un_mot' => 'Una parlla sola à a volta',
	'item_ajout_mots_cles' => 'Auturizà l’usu di segni in i fori',
	'item_non_ajout_mots_cles' => 'Ùn auturizà l’usu di parulle chjave in i fori',
	'item_non_utiliser_config_groupe_mots_cles' => 'Ùn aduprà a cunfigurazione avanzata di i gruppi di segni',
	'item_non_utiliser_mots_cles' => 'Ùn aduprà micca i segni',
	'item_utiliser_config_groupe_mots_cles' => 'Aduprà l cunfigurazione avanzata di i gruppi di segni',
	'item_utiliser_mots_cles' => 'Aduprà i segni',

	// L
	'logo_mot_cle' => 'LOGO DI U SEGNU',

	// T
	'texte_config_groupe_mots_cles' => 'Vulete attivà a cunfigurazione avanzata di i segni,
  indettendu per esempiu chì si pò sceglie un segnu ùnicu per gruppu, o chì un gruppu hè impurtante ... ?', # MODIF
	'texte_mots_cles' => 'I segni permettenu di creà lee temàtiche frà i vostri artìculi,
  duv’elli sianu piazzati à mezu à e diverse rùbbriche.
  Cusì pudete arricchisce a navigazione di u vostru situ, o puru persunalizà a presentazione di l’artìculi in i vostri mudelli.',
	'texte_mots_cles_dans_forum' => 'Vulete auturizà à i visitori l’adopru di i segni in i fori di u situ pùbblicu ? 
  (Attenti : St’upzione hè abbastanza cumplicata à gestisce cum’ellu ci vole.)',
	'texte_nouveau_mot' => 'Nova parulla',
	'titre_config_groupe_mots_cles' => 'Cunfigurazione di i gruppi di segni',
	'titre_gauche_mots_edit' => 'SEGNU NÙMERU :',
	'titre_mots_cles_dans_forum' => 'Segni in u foru di u situ pùbblicu',
	'titre_mots_tous' => 'I segni',
	'titre_nouveau_groupe' => 'Nuvellu gruppu',
	'titre_page_mots_tous' => 'Segni',
];
